OC.L10N.register(
    "mail",
    {
    "Name" : "பெயர்",
    "Password" : "கடவுச்சொல்",
    "None" : "ஒன்றுமில்லை",
    "Save" : "சேமிக்க ",
    "Connect" : "இணைக்க",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "நீக்குக",
    "Choose" : "தெரிவுசெய்க ",
    "Important" : "முக்கியமான ",
    "Favorites" : "விருப்பங்கள்",
    "Other" : "மற்றவை",
    "Settings" : "அமைப்புகள்",
    "Quota" : "பங்கு",
    "Add folder" : "Add folder",
    "Cancel" : "இரத்து செய்க",
    "Delete folder" : "கோப்பை அழிக்க",
    "General" : "பொதுவான",
    "User" : "User",
    "Host" : "ஓம்புனர்",
    "Port" : "துறை ",
    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
    "Search" : "Search",
    "Refresh" : "மீள் ஏற்றுக",
    "All" : "எல்லாம்"
},
"nplurals=2; plural=(n != 1);");
